Discover Packages
github.com/Adonis2115/go-rest-api
models
package
Version:
v0.0.0-...-d47dbea
Opens a new window with list of versions in this module.
Published: Feb 1, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Book struct {
ID string `json:"id" bson:"_id"`
Title string `json:"title" bson:"title"`
Author string `json:"author" bson:"author"`
ISBN string `json:"isbn" bson:"isbn"`
}
type Library struct {
ID string `json:"id" bson:"_id"`
Name string `json:"name" bson:"name"`
Address string `json:"address" bson:"address"`
Books []Book
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.